<br>
<div align="left">
    <img src="{{ userObj.avater }}"
        class="mdui-img-fluid mdui-img-circle" width="200" height="200"><br>
    <div style="white-space:nowrap" class="mdui-typo-headline"><strong>{{ userObj.nickname }}</strong>
        <div class="mdui-chip">

            <span class="mdui-chip-title">{{ userObj.user_group }}</span>
        </div>
    </div>


    <br>

    <div class="mdui-typo">
        <p><em>{{ userObj.user_des }}</em></p>

    </div>
    <div class="mdui-divider"></div>
    <div class="mdui-tab" mdui-tab>
        <a href="#post" class="mdui-ripple">帖子</a>
        <a href="#act" class="mdui-ripple">活动</a>
        <a href="#msg" class="mdui-ripple">留言</a>
    </div>
    <div id="post" class="mdui-p-a-2">一些帖子....</div>
    <div id="act" class="mdui-p-a-2">一些活动....</div>
    <div id="msg" class="mdui-p-a-2">给主人留个话吧</div>
</div>